==> vtk-8.0.1-2-armv6h.pkg.tar.xz: vtk/vtkPolygon.java <==
// java wrapper for vtkPolygon object
//

package vtk;
import vtk.*;

public class vtkPolygon extends vtkCell
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetCellType_2();
  public int GetCellType()
    { return GetCellType_2(); }

  private native int GetCellDimension_3();
  public int GetCellDimension()
    { return GetCellDimension_3(); }

  private native int GetNumberOfEdges_4();
  public int GetNumberOfEdges()
    { return GetNumberOfEdges_4(); }

  private native int GetNumberOfFaces_5();
  public int GetNumberOfFaces()
    { return GetNumberOfFaces_5(); }

  private native long GetEdge_6(int id0);
  public vtkCell GetEdge(int id0) {
    long temp = GetEdge_6(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetFace_7(int id0);
  public vtkCell GetFace(int id0) {
    long temp = GetFace_7(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int CellBoundary_8(int id0,double id1[],vtkIdList id2);
  public int CellBoundary(int id0,double id1[],vtkIdList id2)
    { return CellBoundary_8(id0,id1,id2); }

  private native void Contour_9(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10);
  public void Contour(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10)
    { Contour_9(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9,id10); }

  private native void Clip_10(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9);
  public void Clip(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9)
    { Clip_10(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9); }

  private native int Triangulate_11(int id0,vtkIdList id1,vtkPoints id2);
  public int Triangulate(int id0,vtkIdList id1,vtkPoints id2)
    { return Triangulate_11(id0,id1,id2); }

  private native int IsPrimaryCell_12();
  public int IsPrimaryCell()
    { return IsPrimaryCell_12(); }

  private native double ComputeArea_13();
  public double ComputeArea()
    { return ComputeArea_13(); }

  private native void ComputeNormal_14(vtkPoints id0,double id1[]);
  public void ComputeNormal(vtkPoints id0,double id1[])
    { ComputeNormal_14(id0,id1); }

  private native void ComputeNormal_15(vtkIdTypeArray id0,vtkPoints id1,double id2[]);
  public void ComputeNormal(vtkIdTypeArray id0,vtkPoints id1,double id2[])
    { ComputeNormal_15(id0,id1,id2); }

  private native boolean IsConvex_16();
  public boolean IsConvex()
    { return IsConvex_16(); }

  private native boolean IsConvex_17(vtkIdTypeArray id0,vtkPoints id1);
  public boolean IsConvex(vtkIdTypeArray id0,vtkPoints id1)
    { return IsConvex_17(id0,id1); }

  private native boolean IsConvex_18(vtkPoints id0);
  public boolean IsConvex(vtkPoints id0)
    { return IsConvex_18(id0); }

  private native boolean ComputeCentroid_19(vtkIdTypeArray id0,vtkPoints id1,double id2[]);
  public boolean ComputeCentroid(vtkIdTypeArray id0,vtkPoints id1,double id2[])
    { return ComputeCentroid_19(id0,id1,id2); }

  private native int Triangulate_20(vtkIdList id0);
  public int Triangulate(vtkIdList id0)
    { return Triangulate_20(id0); }

  private native int NonDegenerateTriangulate_21(vtkIdList id0);
  public int NonDegenerateTriangulate(vtkIdList id0)
    { return NonDegenerateTriangulate_21(id0); }

  private native int IntersectConvex2DCells_22(vtkCell id0,vtkCell id1,double id2,double id3[],double id4[]);
  public int IntersectConvex2DCells(vtkCell id0,vtkCell id1,double id2,double id3[],double id4[])
    { return IntersectConvex2DCells_22(id0,id1,id2,id3,id4); }

  private native boolean GetUseMVCInterpolation_23();
  public boolean GetUseMVCInterpolation()
    { return GetUseMVCInterpolation_23(); }

  private native void SetUseMVCInterpolation_24(boolean id0);
  public void SetUseMVCInterpolation(boolean id0)
    { SetUseMVCInterpolation_24(id0); }

  public vtkPolygon() { super(); }

  public vtkPolygon(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-1-armv6h.pkg.tar.xz: vtk/vtkPolygon.java <==
// java wrapper for vtkPolygon object
//

package vtk;
import vtk.*;

public class vtkPolygon extends vtkCell
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetCellType_2();
  public int GetCellType()
    { return GetCellType_2(); }

  private native int GetCellDimension_3();
  public int GetCellDimension()
    { return GetCellDimension_3(); }

  private native int GetNumberOfEdges_4();
  public int GetNumberOfEdges()
    { return GetNumberOfEdges_4(); }

  private native int GetNumberOfFaces_5();
  public int GetNumberOfFaces()
    { return GetNumberOfFaces_5(); }

  private native long GetEdge_6(int id0);
  public vtkCell GetEdge(int id0) {
    long temp = GetEdge_6(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetFace_7(int id0);
  public vtkCell GetFace(int id0) {
    long temp = GetFace_7(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int CellBoundary_8(int id0,double id1[],vtkIdList id2);
  public int CellBoundary(int id0,double id1[],vtkIdList id2)
    { return CellBoundary_8(id0,id1,id2); }

  private native void Contour_9(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10);
  public void Contour(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10)
    { Contour_9(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9,id10); }

  private native void Clip_10(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9);
  public void Clip(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9)
    { Clip_10(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9); }

  private native int Triangulate_11(int id0,vtkIdList id1,vtkPoints id2);
  public int Triangulate(int id0,vtkIdList id1,vtkPoints id2)
    { return Triangulate_11(id0,id1,id2); }

  private native int IsPrimaryCell_12();
  public int IsPrimaryCell()
    { return IsPrimaryCell_12(); }

  private native double ComputeArea_13();
  public double ComputeArea()
    { return ComputeArea_13(); }

  private native void ComputeNormal_14(vtkPoints id0,double id1[]);
  public void ComputeNormal(vtkPoints id0,double id1[])
    { ComputeNormal_14(id0,id1); }

  private native void ComputeNormal_15(vtkIdTypeArray id0,vtkPoints id1,double id2[]);
  public void ComputeNormal(vtkIdTypeArray id0,vtkPoints id1,double id2[])
    { ComputeNormal_15(id0,id1,id2); }

  private native boolean IsConvex_16();
  public boolean IsConvex()
    { return IsConvex_16(); }

  private native boolean IsConvex_17(vtkIdTypeArray id0,vtkPoints id1);
  public boolean IsConvex(vtkIdTypeArray id0,vtkPoints id1)
    { return IsConvex_17(id0,id1); }

  private native boolean IsConvex_18(vtkPoints id0);
  public boolean IsConvex(vtkPoints id0)
    { return IsConvex_18(id0); }

  private native boolean ComputeCentroid_19(vtkIdTypeArray id0,vtkPoints id1,double id2[]);
  public boolean ComputeCentroid(vtkIdTypeArray id0,vtkPoints id1,double id2[])
    { return ComputeCentroid_19(id0,id1,id2); }

  private native int Triangulate_20(vtkIdList id0);
  public int Triangulate(vtkIdList id0)
    { return Triangulate_20(id0); }

  private native int NonDegenerateTriangulate_21(vtkIdList id0);
  public int NonDegenerateTriangulate(vtkIdList id0)
    { return NonDegenerateTriangulate_21(id0); }

  private native int BoundedTriangulate_22(vtkIdList id0,double id1);
  public int BoundedTriangulate(vtkIdList id0,double id1)
    { return BoundedTriangulate_22(id0,id1); }

  private native int IntersectConvex2DCells_23(vtkCell id0,vtkCell id1,double id2,double id3[],double id4[]);
  public int IntersectConvex2DCells(vtkCell id0,vtkCell id1,double id2,double id3[],double id4[])
    { return IntersectConvex2DCells_23(id0,id1,id2,id3,id4); }

  private native boolean GetUseMVCInterpolation_24();
  public boolean GetUseMVCInterpolation()
    { return GetUseMVCInterpolation_24(); }

  private native void SetUseMVCInterpolation_25(boolean id0);
  public void SetUseMVCInterpolation(boolean id0)
    { SetUseMVCInterpolation_25(id0); }

  public vtkPolygon() { super(); }

  public vtkPolygon(long id) { super(id); }
  public native long   VTKInit();

}
